---
title: <span class="badge object-type-scalar"></span> Rubles
---
# <span class="badge object-type-scalar"></span> Rubles

Currency: Rubles (₽)

## Definition

```python
# Currency: Rubles (₽)
Rubles: typing.Literal["currencyRUB"] = "currencyRUB"
```
